next_char_boundary

Function next_char_boundary 

pub(crate) fn next_char_boundary(src: &str, from: usize) -> usize
Return the byte offset of the next character boundary at or after from + 1. Used to step over a single Unicode scalar value when accumulating string literal contents.